@@ -1,9 +1,12 @@
 # Imports
 
+from collections import OrderedDict
 from datetime import timedelta
 from decimal import Decimal
+import operator
 import six
-from ..regex import DECIMAL_PATTERN, EMAIL_PATTERN, HUMAN_FRIENDLY_DURATION_PATTERN, STRICT_EMAIL_PATTERN
+from ..regex import DECIMAL_PATTERN, EMAIL_PATTERN, HUMAN_FRIENDLY_DURATION_PATTERN, STRICT_EMAIL_PATTERN, \
+    VARIABLE_NAME_PATTERN
 from ..constants import BOOLEAN_VALUES, FALSE_VALUES, TRUE_VALUES
 
 # Exports
@@ -13,13 +16,18 @@ __all__ = (
     "is_bool",
     "is_decimal",
     "is_email",
+    "is_empty",
     "is_float",
     "is_integer",
+    "is_magic_name",
+    "is_nothing",
     "is_number",
     "is_string",
+    "is_variable_name",
     "smart_cast",
     "to_bool",
     "to_decimal",
+    "to_ordered_dict",
     "to_timedelta",
     "BooleanBecause",
     "DoesNotInstantiate",
@@ -114,6 +122,22 @@ def is_email(value, strict=False):
     return bool(EMAIL_PATTERN.match(value))
 
 
+def is_empty(value):
+    """Indicates whether a given value is an empty string or blank space.
+
+    :param value: The value to be checked. A string is expected, but the value will be forced to a string before
+                  checking.
+
+    :rtype: bool
+
+    """
+    conditions = [
+        str(value).isspace(),
+        len(str(value)) == 0,
+    ]
+    return any(conditions)
+
+
 @boolean_safe
 def is_float(value):
     """Indicates whether the given value is a float.
@@ -132,7 +156,7 @@ def is_float(value):
     try:
         float(value)
         return True
-    except ValueError:
+    except (TypeError, ValueError):
         return False
 
 
@@ -171,6 +195,45 @@ def is_integer(value, cast=False):
     return False
 
 
+def is_magic_name(value):
+    """Indicates whether a given string is a valid Python magic name.
+
+    :param value: The value to be tested.
+    :type value: str
+
+    :rtype: bool
+
+    """
+    conditions = [
+        is_variable_name(value),
+        len(value) >= 5,
+        value[:2] == "__",
+        value[-2:] == "__",
+    ]
+    return all(conditions)
+
+
+def is_nothing(value):
+    """Indicates whether a given variable has no appreciable value, e.g. an empty string, ``None``, or a zero.
+
+    :param value: The value to be checked.
+
+    :rtype: bool
+
+    .. note::
+        Unlike ``is_empty()`` blank spaces are *not* included in the test because (for example) a space *can* add
+        characters to a string.
+
+    """
+    conditions = [
+        value is None,
+        len(str(value)) == 0,
+        value == 0,
+        value == 0.0,
+    ]
+    return any(conditions)
+
+
 @boolean_safe
 def is_number(value):
     """Indicates whether a given value is a number; a decimal, float, or integer.
@@ -207,6 +270,18 @@ def is_string(value):
     return isinstance(value, six.string_types)
 
 
+def is_variable_name(value):
+    """Indicates whether a given string is a valid Python variable name.
+
+    :param value: The value to be tested.
+    :type value: str
+
+    :rtype: bool
+
+    """
+    return bool(VARIABLE_NAME_PATTERN.match(value))
+
+
 def smart_cast(value):
     """Intelligently cast the given value to a Python data type.
 
@@ -286,6 +361,27 @@ def to_decimal(value, fail_silently=True, places=2):
     return round(d, places)
 
 
+def to_ordered_dict(dictionary):
+    """Given a dictionary of simple key/value pairs, sort the values into an ``OrderedDict``.
+
+    :param dictionary: The dictionary to be sorted.
+    :type dictionary: dict
+
+    :rtype: OrderedDict
+
+    :raise: TypeError
+    :raises: A ``TypeError`` if the values are not all of the same type.
+
+    """
+    tuples = sorted(dictionary.items(), key=operator.itemgetter(1))
+
+    d = OrderedDict()
+    for k, v in tuples:
+        d[k] = v
+
+    return d
+
+
 def to_timedelta(value):
     """Parse a duration string in a human "friendly" time format.
 
